@@ -1,5 +1,4 @@
-from pettingzoo.utils.env import AECEnv
-import pettingzoo.utils
+from pettingzoo.utils import AECEnv, ParallelEnv
 import sys
 
 # Initializing pygame initializes audio connections through SDL. SDL uses alsa by default on all Linux systems
@@ -11,4 +10,4 @@ if sys.platform.startswith('linux'):
     os.environ['SDL_AUDIODRIVER'] = 'dsp'
 
 
-__version__ = "1.5.2"
+__version__ = "1.6.0"
