@@ -126,6 +126,8 @@ class Renderer:
         pygame.quit()
 
     def render(self, mode):
+        import os
+        os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
         import pygame
 
         env = self.env
