@@ -7,8 +7,8 @@ import math
 from pettingzoo.magent.render import Renderer
 from pettingzoo.utils import agent_selector
 from .magent_env import magent_parallel_env, make_env
-from pettingzoo.utils._parallel_env import _parallel_env_wrapper
-from pettingzoo.utils.to_parallel import parallel_wrapper_fn
+from pettingzoo.utils.conversions import from_parallel_wrapper
+from pettingzoo.utils.conversions import parallel_wrapper_fn
 from gym.utils import EzPickle
 
 
@@ -25,7 +25,7 @@ def parallel_env(map_size=default_map_size, max_cycles=max_cycles_default, minim
 
 
 def raw_env(map_size=default_map_size, max_cycles=max_cycles_default, minimap_mode=minimap_mode_default, **env_args):
-    return _parallel_env_wrapper(parallel_env(map_size, max_cycles, minimap_mode, **env_args))
+    return from_parallel_wrapper(parallel_env(map_size, max_cycles, minimap_mode, **env_args))
 
 
 env = make_env(raw_env)
