@@ -3,7 +3,8 @@ from .render_test import render_test
 from .seed_test import seed_test
 from .save_obs_test import test_save_obs
 from .max_cycles_test import max_cycles_test
-from .parallel_test import parallel_play_test
+from .parallel_test import parallel_api_test
 from .bombardment_test import bombardment_test
 from .performance_benchmark import performance_benchmark
 from .manual_control_test import manual_control_test
+from .state_test import state_test
